@@ -139,7 +139,7 @@ impl GeneralReadout for AndroidGeneralReadout {
         Ok(version)
     }
 
-    fn local_ip(&self, interface: String) -> Result<String, ReadoutError> {
+    fn local_ip(&self, interface: Option<String>) -> Result<String, ReadoutError> {
         crate::shared::local_ip(interface)
     }
 
